local _addon = WYK_ImageViewer

local _slider = function( key, parent, label, minVal, maxVal, stepVal, defaultVal, getfunc, setfunc )
	local sliderData = {
		width = "half",
		tooltip = nil,
		name = label,
		min = minVal,
		max = maxVal,
		step = stepVal,
		warning = nil,
		disabled = false,
		default = defaultVal,
		getFunc = getfunc,
		setFunc = setfunc,
	}
	local elem = LAMCreateControl.slider(parent, sliderData, key)
	local scrollwheel = function(self, delta, ctrl, alt, shift) 
		local value = elem.slider:GetValue()
		if delta > 0 then
			if value < maxVal then
				value = value+1
				elem.slider:SetValue(value)
				elem.slidervalue:SetText(value)
			end
		else
			if value > minVal then
				value = value-1
				elem.slider:SetValue(value)
				elem.slidervalue:SetText(value)
			end
		end
		local ui = _G[_addon.__uiKey]
		if ui then 
			ui.data[key] = value
			ui.loadImage() 
		end
	end
	elem.label:SetHorizontalAlignment(_addon.GLOBAL.TextAlign["h"]["center"])
	elem.label:SetVerticalAlignment(_addon.GLOBAL.TextAlign["v"]["bottom"])
	elem.slider:ClearAnchors()
	elem.slider:SetAnchor( TOP, elem.label, BOTTOM, 0, 0 )
	elem.label:SetMouseEnabled( true )
	elem.label:SetHandler( "OnMouseWheel", scrollwheel )
	elem.slider:SetHandler( "OnMouseWheel", scrollwheel )
	elem.slidervalue:SetHandler( "OnMouseWheel", scrollwheel )
	elem.scroll = scrollwheel
	return elem
end

local _make = function()
	local w, h = 280, 238
	local key = _addon.__uiKey
	local ui = _addon.Frames.__NewTopLevel( key )
		:SetDimensions( w, h )
		:SetAnchor( CENTER, GuiRoot, CENTER, 0, 0 )
		:SetMovable( false )
		:SetHidden( true )
	.__END
	ui.BG = _addon.Frames.__NewBackdrop( key, ui )
		:SetAnchor( CENTER, ui, CENTER, 0, 0 )
		:SetDimensions( w, h )
		:SetCenterColor( .25, .25, .25, .95 )
		:SetEdgeColor( 0, 0, 0, 1 )
		:SetEdgeTexture( "", 8, 1, 1 )
		:SetAlpha( 1 )
		:SetHidden( true )
	.__END
	ui.Show = function(self)
		self:SetHidden( false )
		self.BG:SetHidden( false )
	end
	ui.Hide = function(self)
		self:SetHidden( true )
		self.BG:SetHidden( true )
	end
	ui.Toggle = function(self)
		local setTo = self:IsHidden()
		self:SetHidden( not setTo )
		self.BG:SetHidden( not setTo )
		ui.ImageSlider:SetHidden( not setTo )
	end
	ui.data = {}
	
	ui.BG.panel = {}		-- to ghost LAM2
	ui.BG.panel.data = {}	-- to ghost LAM2
	
	ui.loadImage = function() return end
	
	ui.ImageNameBG = WINDOW_MANAGER:CreateControlFromVirtual(nil, ui.BG, "ZO_EditBackdrop")
	ui.ImageNameBG:SetDimensions(w-12, 16)
	ui.ImageNameBG:SetAnchor(TOP, slider, BOTTOM, 0, 0)
	ui.ImageName = WINDOW_MANAGER:CreateControlFromVirtual(nil, ui.ImageNameBG, "ZO_DefaultEditForBackdrop")
	ui.ImageName:ClearAnchors()
	ui.ImageName:SetAnchor(TOPLEFT, ui.ImageNameBG, TOPLEFT, 3, 1)
	ui.ImageName:SetAnchor(BOTTOMRIGHT, ui.ImageNameBG, BOTTOMRIGHT, -3, -1)
	ui.ImageName:SetFont("ZoFontGameSmall")
	ui.ImageName:SetEditEnabled( false )
	
	ui.ImageSlider = _slider( 
		key.."ImageSlider", ui.BG, "Image Index", 
		1, _addon:GetCountOf( _addon.GLOBAL.GameImages ), 1, 1,
		function() return ui.data[key.."ImageSlider"] or 1; end,
		function(val) ui.data[key.."ImageSlider"] = val; ui.loadImage(); end
	)
	
	ui.ImageSlider:SetAnchor( TOP, ui.BG, TOP, 0, 4 )
	ui.ImageSlider:SetParent( ui.BG )
	
	ui.ImageNameBG:ClearAnchors()
	ui.ImageNameBG:SetAnchor( TOP, ui.ImageSlider, BOTTOM, 0, 12 )
	
	ui.Image = _addon.Frames.__NewTexture( key.."Image", ui.BG )
		:SetDimensions( 128, 128)
		:SetAnchor( TOP, ui.ImageNameBG, BOTTOM, 0, 12 )
		:SetTexture( iNormal )
		:SetMouseEnabled( true )
		:SetHandler( "OnMouseWheel", function(...) ui.ImageSlider.scroll( ... ) end )
	.__END
	
	ui.loadImage = function()
		local img = ui.data[key.."ImageSlider"] or 1
		ui.ImageName:SetText( _addon.GLOBAL.GameImages[img] )
		ui.Image:SetTexture( _addon.GLOBAL.GameImages[img] )
	end
	
	ui.loadImage()
	
	return ui
end

function _addon.ui:Create()
	return _G[_addon.__uiKey] or _make()
end

function _addon.ui:Toggle()
	local ui = _addon.ui:Create()
	ui:Toggle()
end

WYK_ImageViewer = _addon
